hostcapabilities

package module
v0.158.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 4, 2026 License: Apache-2.0 Imports: 3 Imported by: 5

Documentation

Overview

Package hostcapabilities provides interfaces that can be implemented by the host to provide additional capabilities.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type ComponentFactory added in v0.124.0

type ComponentFactory interface {
	// GetFactory returns the component factory for the given
	// component type
	GetFactory(kind component.Kind, componentType component.Type) component.Factory
}

ComponentFactory is an interface that may be implemented by the host to provide a component's factory

type ExposeExporters deprecated

type ExposeExporters interface {
	GetExporters() map[pipeline.Signal]map[component.ID]component.Component
}

ExposeExporters is an interface that may be implemented by the host to provide access to the exporters that were used to build the host.

Deprecated: [v0.121.0] Will be removed in Service 1.0. See: https://github.com/open-telemetry/opentelemetry-collector/issues/7370 for service 1.0

type ModuleInfo

type ModuleInfo interface {
	// GetModuleInfos returns the module information for the host
	// i.e. Receivers, Processors, Exporters, Extensions, and Connectors
	GetModuleInfos() moduleinfo.ModuleInfos
}

ModuleInfo is an interface that may be implemented by the host to provide information about modules that were used to build the host.

Jump to